<?php

namespace Drupal\style_selector\Services;

use Drupal\Component\Utility\Html;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Class Utility.
 *
 * Helper methods.
 */
class Utility {

  /**
   * The config factory object.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Config name.
   *
   * @var string
   */
  protected const CONFIG_NAME = 'style_selector.settings';

  /**
   * Default Style Selector element properties.
   * @todo Move these to configurable settings?
   *
   * @var array
   */
  protected const DEFAULTS = [
    'color_prop' => 'background-color',
    'extra_classes' => '',
    'empty_option' => 'None',
    'ui_settings' => [
      'alpha_grid' => TRUE,
      'check_icon' => TRUE,
      'empty_icon' => TRUE,
      'text_icon' => FALSE,
    ],
    'ui_variant' => [
      'compact' => [
        'type' => 'round',
        'size' => 'default',
      ],
    ],
  ];

  /**
   * The constructor.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * Get a value from the default properties array.
   *
   * @param string $name
   *   The property name.
   *
   * @return mixed
   *   The default value, or NULL if not found.
   */
  public function getDefault(string $name) {
    return self::DEFAULTS[$name] ?? NULL;
  }

  /**
   * Get all default properties.
   *
   * @return array
   *   The full default properties array.
   */
  public function getDefaults() {
    return self::DEFAULTS;
  }

  /**
   * Get an array of valid CSS class identifiers.
   *
   * @param mixed $classes
   *   An array or space-separated list of class identifiers.
   *
   * @param string $prefix
   *   Optional. String value to prepend to each class identifier.
   *
   * @return array
   *   An array of valid, sanitized CSS class identifiers.
   */
  public function getClasses(mixed $classes, string $prefix = '') {
    $validated = [];
    if (!empty($classes)) {
      if (is_array($classes)) {
        $validated = $this->sanitizeClasses($classes, $prefix);
      }
      else if (is_string($classes)) {
        $validated = $this->sanitizeClasses(array_filter(explode(' ', $classes)), $prefix);
      }
    }
    return $validated;
  }

  /**
   * Get a space-separated list of valid class identifiers.
   *
   * @param mixed $classes
   *   List of class identifiers to be sanitized.
   *
   * @param string $prefix
   *   Optional. String value to prepend to each class identifier.
   *
   * @return string
   *   A space-separated list of sanitized CSS class identifiers.
   */
  public function getClassList(mixed $classes, string $prefix = '') {
    return implode(' ', $this->getClasses($classes, $prefix));
  }

  /**
   * Validate/sanitize and array of CSS class identifiers.
   *
   * @param array $classes
   *   Array of class identifieres to be sanitized.
   *
   * @param string $prefix
   *   Options. Stirng value to prepend to each class identifier.
   *
   * @return array
   *   An array of valid CSS class identiriers.
   */
  public function sanitizeClasses(array $classes, string $prefix = '') {
    $sanitized = [];
    foreach ($classes as $class) {
      $sanitized[] = Html::getClass($prefix . $class);
    }
    return $sanitized;
  }

}
